@@ -1,12 +1,14 @@
+from Classification.Parameter.ActivationFunction import ActivationFunction
 from Classification.Parameter.LinearPerceptronParameter import LinearPerceptronParameter
 
 
 class MultiLayerPerceptronParameter(LinearPerceptronParameter):
 
     __hiddenNodes: int
+    __activationFunction: ActivationFunction
 
     def __init__(self, seed: int, learningRate: float, etaDecrease: float, crossValidationRatio: float, epoch: int,
-                 hiddenNodes: int):
+                 hiddenNodes: int, activationFunction: ActivationFunction):
         """
         Parameters of the multi layer perceptron algorithm.
 
@@ -24,9 +26,12 @@ class MultiLayerPerceptronParameter(LinearPerceptronParameter):
             Integer value for epoch number of the algorithm.
         hiddenNodes : int
             Integer value for the number of hidden nodes.
+        activationFunction : ActivationFunction
+            Activation function.
         """
         super().__init__(seed, learningRate, etaDecrease, crossValidationRatio, epoch)
         self.__hiddenNodes = hiddenNodes
+        self.__activationFunction = activationFunction
 
     def getHiddenNodes(self) -> int:
         """
@@ -38,3 +43,14 @@ class MultiLayerPerceptronParameter(LinearPerceptronParameter):
             The hiddenNodes.
         """
         return self.__hiddenNodes
+
+    def getActivationFunction(self) -> ActivationFunction:
+        """
+        Accessor for the activationFunction.
+
+        RETURNS
+        -------
+        int
+            The activation function.
+        """
+        return self.__activationFunction
